/*++

TSS Core Service structures

*/

#ifndef __TCS_STRUCT_H__
#define __TCS_STRUCT_H__

#include <tss_tcm/tpm.h>
#include <tss_tcm/tss_structs.h>
#include <tss_tcm/tcs_typedef.h>

typedef struct tdTCS_AUTH
{
    TCS_AUTHHANDLE  AuthHandle;
    TPM_NONCE       NonceOdd;   // system  
    TPM_NONCE       NonceEven;   // TPM   
    TSS_BOOL        fContinueAuthSession;
    TPM_AUTHDATA    HMAC;
} TCS_AUTH;


typedef struct tdTCM_AUTH_SESSION
{
	TSS_HCONTEXT    tspContext;

	TSS_HPOLICY     hPolicy;
	TPM_SECRET      secret;

	TPM_ENTITY_TYPE entityType;
	UINT32          entityValue;
	TPM_NONCE       NonceOdd;
	TPM_AUTHDATA    inHMAC;
	
	TPM_SECRET      sessionKey;
	TPM_NONCE       NonceEven;	
	TPM_AUTHDATA    outHMAC;


	TCM_SEQ         seq;
    TPM_AUTHHANDLE  AuthHandle;
    TPM_AUTHDATA    HMAC;

	//just for compatibility,do not use
    TSS_BOOL        fContinueAuthSession;

} TCM_AUTH_SESSION;

// This is kept for legacy compatibility
typedef TCM_AUTH_SESSION    TPM_AUTH;

typedef struct tdTCS_LOADKEY_INFO
{
    TSS_UUID   keyUUID;
    TSS_UUID   parentKeyUUID;
    TPM_DIGEST  paramDigest; // SHA1 digest of the TPM_LoadKey
                             // Command input parameters
                             // As defined in TPM Main Specification
    TPM_AUTH   authData;     // Data regarding a valid auth
                             // Session including the
                             // HMAC digest
} TCS_LOADKEY_INFO;

#endif // __TCS_STRUCT_H__

